@@ -339,6 +339,7 @@ class VtkRemoteLocalView(HtmlElement):
     ...   # Just VtkRemoteLocalView params
     ...   namespace=...,           # Prefix for variables and triggers. See below. (required)
     ...   mode="local",            # Decide between local or remote. See below.
+    ...   disable_auto_switch=True # Skip automatic remote rendering switch while local rendering is pending
     ...
     ...   # VtkRemoteView params
     ...   **remote_view_params,
@@ -385,6 +386,7 @@ class VtkRemoteLocalView(HtmlElement):
 
         # Provide mandatory attributes
         self._attributes["ref"] = f'ref="{self.__ref}"'
+        self._attributes["refprefix"] = f'refPrefix="{self.__ref}"'
         self._attributes["view_id"] = f':viewId="{self.__view_key_id}"'
         self._attributes["view_state"] = f':viewState="{self.__scene_id}"'
         self._attributes["namespace"] = f'namespace="{__ns}"'
@@ -392,11 +394,15 @@ class VtkRemoteLocalView(HtmlElement):
         self._attr_names += [
             # "mode", # <--- Managed by hand above
             "context_name",
-            "interactive_quality",
-            "interactive_ratio",
+            ("enable_picking", "enablePicking"),
+            ("interactive_quality", "interactiveQuality"),
+            ("interactive_ratio", "interactiveRatio"),
+            ("still_ratio", "stillRatio"),
+            ("still_quality", "stillQuality"),
             ("interactor_events", "interactorEvents"),
             "interactor_settings",
             ("box_selection", "boxSelection"),
+            ("disable_auto_switch", "disableAutoSwitch"),
         ]
         self._event_names += [
             "resize",
@@ -448,7 +454,12 @@ class VtkRemoteLocalView(HtmlElement):
         """
         Force update to geometry
         """
-        self.server.state[self.__scene_id] = MODULE.scene(self.__view, reset_camera)
+        if self.server.protocol:
+            delta_state = MODULE.scene(self.__view, new_state=False)
+            self.server.protocol.publish("trame.vtk.delta", delta_state)
+
+        full_state = MODULE.scene(self.__view, new_state=True)
+        self.server.state[self.__scene_id] = full_state
 
     def update_image(self, reset_camera=False):
         """
@@ -466,7 +477,36 @@ class VtkRemoteLocalView(HtmlElement):
         # need to do both to keep things in sync
         if self.__rendering:
             self.update_image(reset_camera)
-        self.update_geometry(reset_camera)
+        self.update_geometry()
+
+        if reset_camera:
+            self.server.js_call(
+                self.__ref,
+                "setCamera",
+                MODULE.camera(self.__view),
+            )
+
+    def push_camera(self, camera=None, center_of_rotation=None, **kwargs):
+        if camera is None:
+            camera = self.__view.GetRenderers().GetFirstRenderer().GetActiveCamera()
+
+        camera_params = dict(
+            position=camera.GetPosition(),
+            focalPoint=camera.GetFocalPoint(),
+            viewUp=camera.GetViewUp(),
+            parallelProjection=camera.GetParallelProjection(),
+            parallelScale=camera.GetParallelScale(),
+            viewAngle=camera.GetViewAngle(),
+        )
+
+        if center_of_rotation is not None:
+            camera_params["centerOfRotation"] = center_of_rotation
+
+        self.server.js_call(
+            self.__ref,
+            "setCamera",
+            camera_params,
+        )
 
     def replace_view(self, new_view, **kwargs):
         self.server.state[self.__view_key_id] = MODULE.id(new_view)
@@ -536,11 +576,14 @@ class VtkRemoteView(HtmlElement):
         self._attributes["ref"] = f'ref="{ref}"'
         self._attributes["view_id"] = f':viewId="{self.__view_key_id}"'
         self._attr_names += [
-            "enable_picking",
-            "interactive_quality",
-            "interactive_ratio",
+            ("enable_picking", "enablePicking"),
+            ("interactive_quality", "interactiveQuality"),
+            ("interactive_ratio", "interactiveRatio"),
+            ("still_ratio", "stillRatio"),
+            ("still_quality", "stillQuality"),
             ("interactor_events", "interactorEvents"),
             ("box_selection", "boxSelection"),
+            "visible",
         ]
         self._event_names += [
             ("box_selection_change", "BoxSelection"),
@@ -644,7 +687,7 @@ class VtkLocalView(HtmlElement):
         self._attr_names += [
             ("interactor_events", "interactorEvents"),
             "interactor_settings",
-            "context_name",
+            ("context_name", "contextName"),
             ("box_selection", "boxSelection"),
         ]
         self._event_names += [
@@ -720,6 +763,28 @@ class VtkLocalView(HtmlElement):
     def resize(self, **kwargs):
         self.server.js_call(ref=self.__ref, method="resize")
 
+    def push_camera(self, camera=None, center_of_rotation=None, **kwargs):
+        if camera is None:
+            camera = self.__view.GetRenderers().GetFirstRenderer().GetActiveCamera()
+
+        camera_params = dict(
+            position=camera.GetPosition(),
+            focalPoint=camera.GetFocalPoint(),
+            viewUp=camera.GetViewUp(),
+            parallelProjection=camera.GetParallelProjection(),
+            parallelScale=camera.GetParallelScale(),
+            viewAngle=camera.GetViewAngle(),
+        )
+
+        if center_of_rotation is not None:
+            camera_params["centerOfRotation"] = center_of_rotation
+
+        self.server.js_call(
+            self.__ref,
+            "setCamera",
+            camera_params,
+        )
+
 
 class VtkView(HtmlElement):
     def __init__(self, children=None, ref="view", **kwargs):
